@@ -3,9 +3,9 @@
 
 tol <- sqrt(.Machine$double.eps)
 # Test that functions return proper values
-principleBranchAnswers <- runif(5000, min = -1, max = 703.22703310477016)
+principleBranchAnswers <- runif(5000L, min = -1, max = 703.22703310477016)
 principleBranchTests <- principleBranchAnswers * exp(principleBranchAnswers)
-secondaryBranchAnswers <- runif(5000, min = -714.96865723796657, max = -1)
+secondaryBranchAnswers <- runif(5000L, min = -714.96865723796657, max = -1)
 secondaryBranchTests <- secondaryBranchAnswers * exp(secondaryBranchAnswers)
 
 # Test that function works properly in general
@@ -14,13 +14,18 @@ expect_equal(lambertW0(principleBranchTests), principleBranchAnswers,
 expect_equal(lambertWm1(secondaryBranchTests), secondaryBranchAnswers,
              tolerance = tol)
 
+# Specific for CodeCov
+x <- 200
+z <- x * exp(x)
+expect_equal(x, lambertW0(z), tolerance = tol)
+
 # Test that function works properly for larger numbers
 expect_equal(lambertW0(1000) * exp(lambertW0(1000)), 1000, tolerance = tol)
 
 # Test that function behaves properly near 0
-V0 <- seq(-2e-2, 2e-2, 2e-6)
-V0E <- V0 * exp(V0)
-expect_equal(lambertW0(V0E), V0, tolerance = tol)
+v0 <- seq(-2e-2, 2e-2, 2e-6)
+v0E <- v0 * exp(v0)
+expect_equal(lambertW0(v0E), v0, tolerance = tol)
 
 # Test that W0 behaves properly VERY close to 0
 expect_identical(lambertW0(1e-275), 1e-275)
@@ -33,9 +38,9 @@ expect_identical(lambertWm1(-1 / exp(1)), -1)
 
 # Test that function behaves properly near its asymptotes
 L <- seq(1e-6 - exp(-1), -0.25, 3e-6)
-V0 <- lambertW0(L)
+v0 <- lambertW0(L)
 vm1 <- lambertWm1(L)
-expect_equal(V0 * exp(V0), L, tolerance = tol)
+expect_equal(v0 * exp(v0), L, tolerance = tol)
 expect_equal(vm1 * exp(vm1), L, tolerance = tol)
 
 vm1 <- seq(-714, -714.96865, -3e-5)
