@@ -38,12 +38,10 @@ Fritsch, F. N.; Shafer, R. E. & Crowley, W. P.
 
 // [[Rcpp::depends(RcppParallel)]]
 // [[Rcpp::interfaces(r, cpp)]]
+#include <Rmath.h>
 #include <Rcpp.h>
 #include <RcppParallel.h>
 
-#define _USE_MATH_DEFINES
-#include <cmath>
-
 using namespace Rcpp;
 using namespace RcppParallel;
 
@@ -234,7 +232,7 @@ struct LWm1 : public Worker
 NumericVector lambertW0_C(NumericVector x) {
   // allocate the output vector
   NumericVector output(x.size());
-  // Lambert W0 functor (pass input and output matrixes)
+  // Lambert W0 functor (pass input and output matrices)
   LW0 LW0(x, output);
   // call parallelFor to do the work
   parallelFor(0, x.length(), LW0, 4);
@@ -246,7 +244,7 @@ NumericVector lambertW0_C(NumericVector x) {
 NumericVector lambertWm1_C(NumericVector x) {
   // allocate the output vector
   NumericVector output(x.size());
-  // Lambert Wm1 functor (pass input and output matrixes)
+  // Lambert Wm1 functor (pass input and output matrices)
   LWm1 LWm1(x, output);
   // call parallelFor to do the work
   parallelFor(0, x.length(), LWm1, 4);
